# pysymphony

[![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/compositionlabs/pysymphony/blob/main/example.ipynb)

Installation Instructions:

1. Install the package:
```bash
pip install pysymphony
```

2. Set up the API key:
```bash
export SYMPHONY_API_KEY=<your_api_key>
```

3. Start using the package!
Refer the [example.ipynb](./example.ipynb) ([![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/compositionlabs/pysymphony/blob/main/example.ipynb)) for more details.